@@ -8,6 +8,6 @@ URLS = {
     "DISBURSE_STATUS": "/api/remit-status",
     "GET_BALANCE": "/api/balance",
     "GENERATE_VA": "/api/generate-static-va",
-    "VA_INFO": "/api/static-virtual-account/",
+    "VA_INFO": "/api/static-virtual-account",
     "VA_TRANSACTIONS": "/api/va-tx-history/",
 }
